package
Version:
v0.0.0-...-d21d676
Opens a new window with list of versions in this module.
Published: Mar 17, 2024
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
CreateDB : creates the db file if it doesn't exist.
GetDBPath : Gives the file path of the database file.
func Migrate(db *gorm.DB, models []struct{})
Migrate : Migrates the structs from the array of given structs.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.